@@ -276,7 +276,7 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
 
     // skip lines if we have to
 
-    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file) == NULL) {}
 
     if (ipts)
     {
@@ -640,7 +640,7 @@ BOOL LASreaderTXT::open(FILE* file, const CHAR* file_name, U8 point_type, const
   this->skip_lines = skip_lines;
   if (skip_lines)
   {
-    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file) == NULL) {}
   }
   else if (ipts)
   {
@@ -1095,7 +1095,7 @@ BOOL LASreaderTXT::seek(const I64 p_index)
     fseek(file, 0, SEEK_SET);
     // skip lines if we have to
     int i;
-    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
+    for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file) == NULL) {}
     // read the first line with full parse_string
     i = 0;
     while (fgets(line, 512, file))
@@ -1264,7 +1264,7 @@ BOOL LASreaderTXT::reopen(const char* file_name)
 
   // skip lines if we have to
 
-  for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file));
+  for (i = 0; i < skip_lines; i++) if (fgets(line, 512, file) == NULL) {}
 
   // read the first line with full parse_string
 
@@ -1830,7 +1830,7 @@ BOOL LASreaderTXT::parse(const char* parse_string)
     }
     else if (p[0] == 'H') // we expect a hexadecimal coded RGB color
     {
-      I32 hex_value;
+      U32 hex_value;
       char hex_string[3] = "__";
       while (l[0] && (l[0] == ' ' || l[0] == ',' || l[0] == '\t' || l[0] == ';' || l[0] == '\"')) l++; // first skip white spaces and quotes
       if (l[0] == 0) return FALSE;
@@ -1848,7 +1848,7 @@ BOOL LASreaderTXT::parse(const char* parse_string)
     }
     else if (p[0] == 'J') // we expect a hexadecimal coded intensity
     {
-      I32 hex_value;
+      U32 hex_value;
       while (l[0] && (l[0] == ' ' || l[0] == ',' || l[0] == '\t' || l[0] == ';' || l[0] == '\"')) l++; // first skip white spaces and quotes
       if (l[0] == 0) return FALSE;
       sscanf(l,"%x",&hex_value);
