@@ -27,7 +27,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>
 ===============================================================================
 */
 
-// [[Rcpp::depends(BH)]]
+#if defined(__GNUC__) && (__GNUC__ < 5) && !defined(__clang__) && !defined(__llvm__) && !defined(__INTEL_COMPILER)
+#include "gcc_4_9_patch/std_is_trivially_substitutes.hpp"
+#include "gcc_4_9_patch/boost_compare_patched.hpp"
+#endif
 
 #include <Rcpp.h>
 #include <boost/geometry.hpp>
